@@ -54,6 +54,7 @@ class DefaultTestSettings:
         add_dashboard_middleware=None,
         add_lab_dashboard_middleware=None,
         add_adverse_event_dashboard_middleware=None,
+        add_multisite_middleware=None,
         template_dirs=None,
         excluded_apps=None,
         selected_database: str = None,
@@ -95,6 +96,8 @@ class DefaultTestSettings:
             self.settings["TEMPLATES"][0]["DIRS"] = template_dirs
 
         self.update_root_urlconf(use_test_urls)
+        if not add_multisite_middleware:
+            self.settings["MIDDLEWARE"].remove("multisite.middleware.DynamicSiteMiddleware")
 
         if add_dashboard_middleware:
             self.settings["MIDDLEWARE"].extend(
@@ -174,18 +177,19 @@ class DefaultTestSettings:
             MIDDLEWARE=[
                 "django.middleware.security.SecurityMiddleware",
                 "django.contrib.sessions.middleware.SessionMiddleware",
-                # "django.middleware.locale.LocaleMiddleware",
+                "django.middleware.locale.LocaleMiddleware",
                 "django.middleware.common.CommonMiddleware",
                 "django.middleware.csrf.CsrfViewMiddleware",
                 "django.contrib.auth.middleware.AuthenticationMiddleware",
                 "django.contrib.messages.middleware.MessageMiddleware",
                 "django.middleware.clickjacking.XFrameOptionsMiddleware",
+                "multisite.middleware.DynamicSiteMiddleware",
                 "django.contrib.sites.middleware.CurrentSiteMiddleware",
             ],
-            LANGUAGE_CODE="en-us",
+            LANGUAGE_CODE="en",
             TIME_ZONE="UTC",
-            USE_I18N=False,
-            USE_L10N=False,
+            USE_I18N=True,
+            USE_L10N=True,
             USE_TZ=True,
             DEFAULT_AUTO_FIELD="django.db.models.BigAutoField",
             EDC_BOOTSTRAP=3,
@@ -275,8 +279,8 @@ class DefaultTestSettings:
             "default": {
                 "ENGINE": "django.db.backends.mysql",
                 "NAME": "test",
-                "USER": "root",
-                "PASSWORD": "password",
+                "USER": "mysql",
+                "PASSWORD": "mysql",
                 "HOST": "127.0.0.1",
                 "PORT": 3306,
             }
@@ -287,8 +291,8 @@ class DefaultTestSettings:
                     "client": {
                         "ENGINE": "django.db.backends.mysql",
                         "NAME": "other",
-                        "USER": "root",
-                        "PASSWORD": "password",
+                        "USER": "mysql",
+                        "PASSWORD": "mysql",
                         "HOST": "127.0.0.1",
                         "PORT": 3306,
                     }
