@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 from warnings import warn
 
 from django.conf import settings
@@ -10,6 +13,9 @@ from edc_auth.models import Role
 
 style = color_style()
 
+if TYPE_CHECKING:
+    from django.contrib.auth.models import User
+
 
 def get_or_create_group(group_name):
     try:
@@ -21,13 +27,15 @@ def get_or_create_group(group_name):
 
 def login(
     testcase,
-    user=None,
-    superuser=None,
+    user: User | None = None,
+    superuser: bool | None = None,
     groups=None,
     roles=None,
     sites=None,
     redirect_url=None,
+    extra_environ=None,
 ):
+    extra_environ = extra_environ or {}
     user = testcase.user if user is None else user
     user.is_superuser = True if superuser is None else superuser
     if user.is_superuser:
@@ -54,11 +62,16 @@ def login(
     user.userprofile.save()
     user.save()
     user.refresh_from_db()
-    form = (
-        testcase.app.get(reverse(redirect_url or settings.LOGIN_REDIRECT_URL))
-        .maybe_follow()
-        .form
+    response = testcase.app.get(
+        reverse(redirect_url or settings.LOGIN_REDIRECT_URL), extra_environ=extra_environ
     )
+    response = response.maybe_follow(extra_environ=extra_environ)
+    for index, form in response.forms.items():
+        if form.action == "/i18n/setlang/":
+            # exclude the locale form
+            continue
+        else:
+            break
     form["username"] = user.username
     form["password"] = "pass"  # nosec B105
-    return form.submit()
+    return form.submit(extra_environ=extra_environ)
